.. include:: ../README.rst

Contents
--------

.. toctree::
  :maxdepth: 1

  pages/contributing.rst
  pages/authors.rst
  pages/changelog.rst


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
